Error types shared by every addressable-heap capability.
These types describe outcomes common to a capability - handle validation,
key decreases, key increases - independent of which module implements the
heap. A specific heap family (for example, the radix heaps in
crate::monotone) may report a more detailed error from its own
inherent methods and convert it into one of these when implementing a
shared trait.
Enums
- Decrease
KeyError - An error returned when decreasing an entry’s key in a
DecreaseKeyHeap. - Increase
KeyError - An error returned when increasing an entry’s key in a double-ended addressable heap.
- Invalid
Handle - The reason an addressable heap rejected a handle.